# Dorado data files

dorado-510km-60inc.tle, dorado-510km-sunsync.tle, dorado-625km-60inc.tle, dorado-625km-sunsync.tle
: fake two-line elements for a selection of plausible Dorado orbits,
  created by Craig Markwardt.

goes17.tle
: two-line element for the GOES-17 satellite, a weather satellite that is
  currently on orbit. Its geostationary orbit is used as a proxy for ULTRASAT.
  Retrieved from Celestrak on April 29, 2021.

vela1.tle
: two-line element for the VELA 1 satellite, a historically significant
  gamma-ray mission with an orbit that is similar to the super-geostationary,
  highly elliptical orbit that is under consideration for UVEX. Retrieved from
  Celestrak on April 29, 2021.
